#
# spec file for package python-geventhttpclient
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-geventhttpclient
Version:        2.0.11
Release:        1.1
Summary:        HTTP client library for gevent
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/gwik/geventhttpclient
Source:         https://files.pythonhosted.org/packages/source/g/geventhttpclient/geventhttpclient-%{version}.tar.gz
BuildRequires:  %{python_module Brotli}
BuildRequires:  %{python_module certifi}
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module dpkt}
BuildRequires:  %{python_module gevent}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module six}
%if 0%{?suse_version} <= 1500
BuildRequires:  python-mock
%endif
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Brotli
Requires:       python-certifi
Requires:       python-gevent
%python_subpackages

%description
A concurrent HTTP client library for Python using gevent.

geventhttpclient uses a HTTP parser, written in C, originating from
nginx, extracted and modified by Joyent.

geventhttpclient has been designed for high concurrency and
streaming, and supports HTTP/1.1 persistent connections. More
generally, it is designed for pulling from REST APIs and streaming
APIs like Twitter's.

%prep
%autosetup -p1 -n geventhttpclient-%{version}
# don't try to set this nonexistent attribute -- gh#gwik/geventhttpclient#137
sed -i '/sock.last_seen_sni/ d' src/geventhttpclient/tests/test_ssl.py

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%check
# test_cookielib_compatibility https://github.com/gwik/geventhttpclient/issues/119
# test_no_module_ssl.py https://github.com/geventhttpclient/geventhttpclient/issues/180
%pytest_arch -m 'not online' -k 'not (test_cookielib_compatibility or test_no_module_ssl)'

%files %{python_files}
%doc README.mdown
%license LICENSE.txt
%{python_sitearch}/geventhttpclient
%{python_sitearch}/geventhttpclient-%{version}*-info

%changelog
* Thu Dec  7 2023 Dirk Müller <dmueller@suse.com>
- update to 2.0.11:
  * Support Python 3.12
  * Disable unit tests for no ssl module + fixes for build
* Fri Aug 25 2023 Markéta Machová <mmachova@suse.com>
- Skip both tests in test_no_module_ssl.py, failing with new gevent
* Thu May  4 2023 Dirk Müller <dmueller@suse.com>
- update to 2.0.9:
  * Add square brackets for Host header when using IPv6 address
  * Enable ppc64le wheels
* Fri Nov  4 2022 pgajdos@suse.com
- version update to 2.0.8
  * lot of changes, see
    https://github.com/geventhttpclient/geventhttpclient/releases
- do not require python-six
- deleted patches
  - remove_mock.patch (upstreamed)
* Tue Feb 16 2021 Ben Greiner <code@bnavigator.de>
- Update to 1.4.5
  * Don't auto parse query string. Add params keyword argument.
- don't try to set a nonexistend attribute for a test
  gh#gwik/geventhttpclient#137
* Mon Dec 14 2020 Benjamin Greiner <code@bnavigator.de>
- Fix condition around BuildRequirement
* Sun Dec 13 2020 Matej Cepl <mcepl@suse.com>
- We don't need to break Python 2.7
* Fri Dec 11 2020 Matej Cepl <mcepl@suse.com>
- Add remove_mock.patch to remove dependency on the external mock
  package (gh#gwik/geventhttpclient#135).
* Sat Aug  1 2020 John Vandenberg <jayvdb@gmail.com>
- Remove gevent-mark-tests.patch and LICENSE-MIT that are
  now incorporated upstream
- Update to v1.4.4
  * Add kwargs to exception objects representation
- from v1.4.3
  * Fix Unhandled UnicodeDecodeError exception if response with
    status 400 and request contains binary payload
- from v1.4.0
  * httpparser: update http parser to 2.9.4
* Tue Jan 14 2020 Tomáš Chvátal <tchvatal@suse.com>
- skip test test_cookielib_compatibility as it is borked upstream
* Fri Mar 22 2019 Tomáš Chvátal <tchvatal@suse.com>
- Add patch to skip online tests:
  * gevent-mark-tests.patch
* Thu Mar 14 2019 Jan Engelhardt <jengelh@inai.de>
- Reduce marketing wording in the description.
* Thu Mar 14 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.3.1:
  * no upstream changelog
- Switch to singlespec
- Enable tests
* Tue Sep  8 2015 tbechtold@suse.com
- Initial packaging (version 1.1.0)
